@@ -587,15 +587,15 @@ class Witter():
                 f5.write("senderName" + str(counter) + " = " + store.get_value(item,0)+"\n")
                 f5.write("senderId" + str(counter) + " = " +store.get_value(item,1)+"\n")
                 tweet = store.get_value(item,2)
-		tweet = tweet.replace("\n","&CR;")
-		f5.write("tweet" + str(counter) + " = " +tweet+"\n")
+                tweet = tweet.replace("\n","&CR;")
+                f5.write("tweet" + str(counter) + " = " +tweet+"\n")
                 #3 is unused now, used to be tweet colour
                 f5.write("tweetId" + str(counter) + " = " +str(store.get_value(item,4))+"\n")
                 f5.write("type" + str(counter)+" = " + str(store.get_value(item,5))+"\n")
                 f5.write("createdAt" + str(counter) + " = " +store.get_value(item,6)+"\n")
                 reply = store.get_value(item,7)
-		reply = reply.replace("\n","&CR;")
-		f5.write("replyTo" + str(counter) + " = " +reply+"\n")
+                reply = reply.replace("\n","&CR;")
+                f5.write("replyTo" + str(counter) + " = " +reply+"\n")
                 f5.write("source" + str(counter) + " = " +store.get_value(item,8)+"\n")
                 #9 is avatar pic
                 formattedTweet = store.get_value(item,10)
@@ -620,12 +620,12 @@ class Witter():
                 senderId = config.get("tweets", "senderId" + str(counter));
                 tweet = config.get("tweets", "tweet" + str(counter));
                 tweet = tweet.replace("&CR;","\n")
-		tweetId = config.get("tweets", "tweetId" + str(counter));
+                tweetId = config.get("tweets", "tweetId" + str(counter));
                 tweet_long_id = float(tweetId)
                 createdAt = config.get("tweets", "createdAt" + str(counter));
                 replyTo = config.get("tweets", "replyTo" + str(counter));
                 replyTo = replyTo.replace("&CR;","\n")
-		type = config.get("tweets", "type" + str(counter));
+                type = config.get("tweets", "type" + str(counter));
                 source = config.get("tweets", "source" + str(counter));
                 formattedTweet = config.get("tweets", "formattedTweet" + str(counter));
                 formattedTweet = formattedTweet.replace("&CR;", "\n")
@@ -640,7 +640,9 @@ class Witter():
                         os.remove("/home/user/.witterPics/" + self.accountdata.servicename + "/" + filename)
                         print "bad file deleted, returning default icon"
                         avatar = gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
-                    avatar = avatar.scale_simple(60, 60, gtk.gdk.INTERP_BILINEAR)
+                else:
+                    avatar = gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
+                avatar = avatar.scale_simple(60, 60, gtk.gdk.INTERP_BILINEAR)
                 tweetstore.append([senderName,senderId,tweet,"",tweet_long_id,type,createdAt,replyTo,source,avatar,formattedTweet])
                 counter=counter+1
                 
@@ -1083,18 +1085,22 @@ class Witter():
             
     def _on_orientation_signal(self, orientation, stand, face, x, y, z):
          if (orientation == 'portrait'):
-            print "switched to portrait"
+            print "switching to portrait"
             self.ui.cell.set_property('wrap-width', 400)
             self.ui.icon_size = 30
             self.ui.load_theme_icons()
             self.ui.define_ui_buttons()
-            
+            #print "show portrait keyboard"
+            #self.ui.show_portrait_keyboard()
+            #print "keybaord should be showing"
          if (orientation == 'landscape'):
-            print "switched to landscape"
+            print "switching to landscape"
             self.ui.cell.set_property('wrap-width', 730)
             self.ui.icon_size = 48
             self.ui.load_theme_icons()
             self.ui.define_ui_buttons()
+            #self.ui.hide_portrait_keyboard()
+         print "refresh current view"
          curView = self.ui.getCurrentView()  
          if (curView == self.ui.TIMELINE_VIEW):
             self.ui.switch_view_to("timeline")
